diff --git a/.eslintrc.js b/.eslintrc.js
index 87fb99b..5e48cd6 100644
--- a/.eslintrc.js
+++ b/.eslintrc.js
@@ -1,12 +1,12 @@
/*
-+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-title ESLint Configuration +
-project nord-terminix +
-repository https://github.com/arcticicestudio/nord-terminix +
-author Arctic Ice Studio +
-email development@arcticicestudio.com +
-copyright Copyright (C) 2017 +
-+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+title ESLint Configuration +
+project nord-tilix +
+repository https://github.com/arcticicestudio/nord-tilix +
+author Arctic Ice Studio +
+email development@arcticicestudio.com +
+copyright Copyright (C) 2017 +
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
[References]
ESLint
diff --git a/.travis.yml b/.travis.yml
index 132f4a7..8a86387 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -1,11 +1,11 @@
-# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-# title Travis CI Build Configuration +
-# project nord-terminix +
-# repository https://github.com/arcticicestudio/nord-terminix +
-# author Arctic Ice Studio +
-# email development@arcticicestudio.com +
-# copyright Copyright (C) 2017 +
-# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+# title Travis CI Build Configuration +
+# project nord-tilix +
+# repository https://github.com/arcticicestudio/nord-tilix +
+# author Arctic Ice Studio +
+# email development@arcticicestudio.com +
+# copyright Copyright (C) 2017 +
+# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#
# [References]
# Travis CI Documentation
diff --git a/CHANGELOG.md b/CHANGELOG.md
index fd91f51..6a64d4a 100644
--- a/CHANGELOG.md
+++ b/CHANGELOG.md
@@ -1,33 +1,33 @@
-
+
-
+
---
# 0.2.0
*2017-02-21*
## Features
-❯ Implemented support for advanced color settings including [badges](https://gnunn1.github.io/terminix-web/manual/badges). Disabled by default to allow users to enable them when they fit their needs. (@arcticicestudio, #9, cdf1c580)
+❯ Implemented support for advanced color settings including [badges](https://gnunn1.github.io/tilix-web/manual/badges). Disabled by default to allow users to enable them when they fit their needs. (@arcticicestudio, #9, cdf1c580)
-Advanced Color Settings
Badges
+Advanced Color Settings
Badges
## Improvements
### Toolbox
-❯ Implemented a [`gulpfile.js`](https://github.com/arcticicestudio/nord-terminix/blob/develop/gulpfile.js) to run ESLint with defined [`.eslintrc.js`](https://github.com/arcticicestudio/nord-terminix/blob/develop/.eslintrc.js) rules. (@arcticicestudio, #10, 1b92f2f2)
+❯ Implemented a [`gulpfile.js`](https://github.com/arcticicestudio/nord-tilix/blob/develop/gulpfile.js) to run ESLint with defined [`.eslintrc.js`](https://github.com/arcticicestudio/nord-tilix/blob/develop/.eslintrc.js) rules. (@arcticicestudio, #10, 1b92f2f2)
### Continuous Integration Builds
-❯ [Circle CI](https://circleci.com/gh/arcticicestudio/nord-terminix) builds are now running against the latest [Node](https://nodejs.org) `6.x.x` version (@arcticicestudio, #10, 1b92f2f2)
-❯ [Travis-CI](https://travis-ci.org/arcticicestudio/nord-terminix) builds are now running against the latest [Node](https://nodejs.org) `6.x.x` and `4.x.x` versions (@arcticicestudio, #10, 1b92f2f2)
-❯ Added support for [EditorConfig](http://editorconfig.org) by defining rules via a [`.editorconfig`](https://github.com/arcticicestudio/nord-terminix/blob/develop/.editorconfig) file. (@arcticicestudio, #11, 748ac20c)
+❯ [Circle CI](https://circleci.com/gh/arcticicestudio/nord-tilix) builds are now running against the latest [Node](https://nodejs.org) `6.x.x` version (@arcticicestudio, #10, 1b92f2f2)
+❯ [Travis-CI](https://travis-ci.org/arcticicestudio/nord-tilix) builds are now running against the latest [Node](https://nodejs.org) `6.x.x` and `4.x.x` versions (@arcticicestudio, #10, 1b92f2f2)
+❯ Added support for [EditorConfig](http://editorconfig.org) by defining rules via a [`.editorconfig`](https://github.com/arcticicestudio/nord-tilix/blob/develop/.editorconfig) file. (@arcticicestudio, #11, 748ac20c)
# 0.1.0
*2016-11-19*
## Features
❯ Implemented the main JSON color scheme file.
-Detailed instructions to install the scheme file can be found in the [README](https://github.com/arcticicestudio/nord-terminix/blob/develop/README.md#installation).
+Detailed instructions to install the scheme file can be found in the [README](https://github.com/arcticicestudio/nord-tilix/blob/develop/README.md#installation).
(@arcticicestudio, #1, b4179195)
-
htop
+
htop
# 0.0.0
*2016-11-19*
diff --git a/README.md b/README.md
index 1cd3955..f35934b 100644
--- a/README.md
+++ b/README.md
@@ -1,23 +1,23 @@
-
+
-
+
-An arctic, north-bluish clean and elegant Terminix color scheme.
+An arctic, north-bluish clean and elegant Tilix color scheme.
Designed for a fluent and clear workflow.
Based on the Nord color palette.
---
-Font: Source Code Pro 12px.
+Font: Source Code Pro 12px.
## Getting started
### Installation
#### Manual
-Copy the [`nord.json`](https://github.com/arcticicestudio/nord-terminix/blob/develop/src/json/nord.json) file to the color schemes directory according to the desired installation type.
+Copy the [`nord.json`](https://github.com/arcticicestudio/nord-tilix/blob/develop/src/json/nord.json) file to the color schemes directory according to the desired installation type.
-Local: `~/.config/terminix/schemes`
-Global: `/usr/share/terminix/schemes`
+Local: `~/.config/tilix/schemes`
+Global: `/usr/share/tilix/schemes`
#### Install Script
The included `install.sh` shell script can be used for an automated installation.
@@ -44,17 +44,17 @@ Syntax: `install.sh [OPTIONS]`
3. Select `Nord` from the *Color scheme* drop-down menu
## Screenshots
-htop
+htop
-Advanced Color Settings
Badges
+Advanced Color Settings
Badges
## Development
-[![](https://img.shields.io/badge/Changelog-0.2.0-81A1C1.svg)](https://github.com/arcticicestudio/nord-terminix/blob/v0.2.0/CHANGELOG.md) [![](https://img.shields.io/badge/Workflow-gitflow--branching--model-81A1C1.svg)](http://nvie.com/posts/a-successful-git-branching-model) [![](https://img.shields.io/badge/Versioning-ArcVer_0.8.0-81A1C1.svg)](https://github.com/arcticicestudio/arcver)
+[![](https://img.shields.io/badge/Changelog-0.2.0-81A1C1.svg)](https://github.com/arcticicestudio/nord-tilix/blob/v0.2.0/CHANGELOG.md) [![](https://img.shields.io/badge/Workflow-gitflow--branching--model-81A1C1.svg)](http://nvie.com/posts/a-successful-git-branching-model) [![](https://img.shields.io/badge/Versioning-ArcVer_0.8.0-81A1C1.svg)](https://github.com/arcticicestudio/arcver)
-Continuous integration builds are running at [Travis-CI](https://travis-ci.org/arcticicestudio/nord-terminix) and [Circle CI](https://circleci.com/bb/arcticicestudio/nord-terminix).
+Continuous integration builds are running at [Travis-CI](https://travis-ci.org/arcticicestudio/nord-tilix) and [Circle CI](https://circleci.com/bb/arcticicestudio/nord-tilix).
### Contribution
-Please report issues/bugs, feature requests and suggestions for improvements to the [issue tracker](https://github.com/arcticicestudio/nord-terminix/issues).
+Please report issues/bugs, feature requests and suggestions for improvements to the [issue tracker](https://github.com/arcticicestudio/nord-tilix/issues).
diff --git a/circle.yml b/circle.yml
index b7d63e8..7b95964 100644
--- a/circle.yml
+++ b/circle.yml
@@ -1,11 +1,11 @@
-# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-# title Circle CI Build Configuration +
-# project nord-terminix +
-# repository https://github.com/arcticicestudio/nord-terminix +
-# author Arctic Ice Studio +
-# email development@arcticicestudio.com +
-# copyright Copyright (C) 2017 +
-# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+# title Circle CI Build Configuration +
+# project nord-tilix +
+# repository https://github.com/arcticicestudio/nord-tilix +
+# author Arctic Ice Studio +
+# email development@arcticicestudio.com +
+# copyright Copyright (C) 2017 +
+# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
#
# [References]
# Circle CI
diff --git a/gulpfile.js b/gulpfile.js
index 46d405a..59448a0 100644
--- a/gulpfile.js
+++ b/gulpfile.js
@@ -1,12 +1,12 @@
/*
-+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-title Project Gulp File +
-project nord-terminix +
-repository https://github.com/arcticicestudio/nord-terminix +
-author Arctic Ice Studio +
-email development@arcticicestudio.com +
-copyright Copyright (C) 2017 +
-+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+title Project Gulp File +
+project nord-tilix +
+repository https://github.com/arcticicestudio/nord-tilix +
+author Arctic Ice Studio +
+email development@arcticicestudio.com +
+copyright Copyright (C) 2017 +
+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
[References]
Gulp
diff --git a/package.json b/package.json
index 67ec88b..343dd2c 100644
--- a/package.json
+++ b/package.json
@@ -1,20 +1,20 @@
{
- "name": "nord-terminix",
- "title": "Nord Terminix",
+ "name": "nord-tilix",
+ "title": "Nord Tilix",
"version": "0.2.0",
- "description": "An arctic, north-bluish clean and elegant Terminix color scheme.",
+ "description": "An arctic, north-bluish clean and elegant Tilix color scheme.",
"author": {
"name": "Arctic Ice Studio",
"email": "development@arcticicestudio.com",
"url": "http://arcticicestudio.com"
},
- "homepage": "https://github.com/arcticicestudio/nord-terminix",
+ "homepage": "https://github.com/arcticicestudio/nord-tilix",
"repository": {
"type": "git",
- "url": "git+https://github.com/arcticicestudio/nord-terminix.git"
+ "url": "git+https://github.com/arcticicestudio/nord-tilix.git"
},
"bugs": {
- "url": "https://github.com/arcticicestudio/nord-terminix/issues"
+ "url": "https://github.com/arcticicestudio/nord-tilix/issues"
},
"license" : "(Apache-2.0 AND CC-BY-SA-4.0)",
"keywords": [
@@ -24,7 +24,7 @@
"bluish",
"clean",
"elegant",
- "terminix",
+ "tilix",
"color",
"scheme"
],
diff --git a/src/json/nord.json b/src/json/nord.json
index f866052..8637e4e 100755
--- a/src/json/nord.json
+++ b/src/json/nord.json
@@ -1,6 +1,6 @@
{
"name": "Nord",
- "comment": "An arctic, north-bluish clean and elegant Terminix color scheme.",
+ "comment": "An arctic, north-bluish clean and elegant Tilix color scheme.",
"foreground-color": "#D8DEE9",
"background-color": "#2E3440",
"badge-color": "#88C0D0",
diff --git a/install.sh b/install.sh
index 27d2429..21ea97c 100755
--- a/install.sh
+++ b/install.sh
@@ -1,12 +1,12 @@
#!/usr/bin/env bash
# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# title Install Script +
# project nord-terminix +
# repository https://github.com/arcticicestudio/nord-terminix +
# author Arctic Ice Studio +
# email development@arcticicestudio.com +
# copyright Copyright (C) 2016 +
# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
set -e
_ct_error="\e[0;31m"
@@ -38,7 +38,7 @@ __cleanup() {
trap '' SIGINT SIGTERM
unset -v _ct_error _ct_success _ct_warning _ct_highlight _ct_primary _ct
unset -v _ctb_error _ctb_success _ctb_warning _ctb_highlight _ctb_primary _ctb _c_reset
- unset -v NORD_TERMINIX_SCRIPT_OPTS COLOR_SCHEME_FILE VERBOSE GLOBAL_INSTALL LOCAL_INSTALL
+ unset -v NORD_TILIX_SCRIPT_OPTS COLOR_SCHEME_FILE VERBOSE GLOBAL_INSTALL LOCAL_INSTALL
unset -f __help __cleanup __log_error __log_success __log_warning __log_info
unset -f __validate_file __local_install __global_install
}
@@ -127,14 +127,14 @@ __validate_file() {
trap "printf '${_ctb_error}User aborted.${_ctb_reset}\n' && exit 1" SIGINT SIGTERM
-NORD_TERMINIX_SCRIPT_OPTS=`getopt -o vghs: --long verbose,global,help,schemefile: -n 'install.sh' -- "$@"`
+NORD_TILIX_SCRIPT_OPTS=`getopt -o vghs: --long verbose,global,help,schemefile: -n 'install.sh' -- "$@"`
COLOR_SCHEME_FILE=src/json/nord.json
VERBOSE=false
GLOBAL_INSTALL=false
-LOCAL_INSTALL_DIR=~/.config/terminix/schemes
-GLOBAL_INSTALL_DIR=/usr/share/terminix/schemes
+LOCAL_INSTALL_DIR=~/.config/tilix/schemes
+GLOBAL_INSTALL_DIR=/usr/share/tilix/schemes
-eval set -- "$NORD_TERMINIX_SCRIPT_OPTS"
+eval set -- "$NORD_TILIX_SCRIPT_OPTS"
while true; do
case "$1" in
-v | --verbose ) VERBOSE=true; shift ;;
@@ -1,12 +1,12 @@
#!/usr/bin/env bash
-# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-# title Install Script +
-# project nord-terminix +
-# repository https://github.com/arcticicestudio/nord-terminix +
-# author Arctic Ice Studio +
-# email development@arcticicestudio.com +
-# copyright Copyright (C) 2016 +
-# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+# title Install Script +
+# project nord-tilix +
+# repository https://github.com/arcticicestudio/nord-tilix +
+# author Arctic Ice Studio +
+# email development@arcticicestudio.com +
+# copyright Copyright (C) 2016 +
+# ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
set -e
_ct_error="\e[0;31m"